from rest_framework import generics

from core.models.conference import Conference, ConferenceTrack

from api.serializers import ConferenceSerializer, ConferenceTrackSerializer
from api.views.mixins import ConferenceSlugMixin


class ConferenceList(generics.ListAPIView):
    serializer_class = ConferenceSerializer

    def get_queryset(self):
        return Conference.objects.accessible_by_user(self.request.user)


class ConferenceDetail(ConferenceSlugMixin, generics.RetrieveAPIView):
    serializer_class = ConferenceSerializer

    def get_object(self, **kwargs):
        return self.conference


class ConferenceTrackList(ConferenceSlugMixin, generics.ListAPIView):
    serializer_class = ConferenceTrackSerializer

    def get_queryset(self, **kwargs):
        return ConferenceTrack.objects.accessible_by_user(self.request.user, self.conference).order_by('name')


class ConferenceTrackDetail(ConferenceSlugMixin, generics.RetrieveAPIView):
    serializer_class = ConferenceTrackSerializer

    def get_object(self, **kwargs):
        track_slug = self.request.resolver_match.kwargs['track']
        return ConferenceTrack.objects.accessible_by_user(self.request.user, self.conference).get(slug=track_slug)
