import logging

from django.contrib import messages
from django.shortcuts import redirect
from django.views.generic import DetailView, ListView

from core.models import ActivityLogChange, ActivityLogEntry, Assembly

from backoffice.views.moderation.mixins import ModerationAdminMixin

logger = logging.getLogger(__name__)


class ModerationAssemblyListView(ModerationAdminMixin, ListView):
    template_name = 'backoffice/moderation_assembly-list.html'

    def get_queryset(self):
        qs = self.conference.assemblies.all().order_by('slug')
        return qs


class ModerationAssemblyDetailView(ModerationAdminMixin, DetailView):
    template_name = 'backoffice/moderation_assembly-detail.html'

    def get_queryset(self):
        # TODO: Check if this is the correct queryset
        qs = self.conference.assemblies.all()
        return qs

    def post(self, request, *args, **kwargs):
        assembly = self.get_object()
        action = request.POST.get('action')

        if action == 'hide':
            changes = {}
            previous_state = assembly.state
            assembly.state = Assembly.State.HIDDEN
            changes['state'] = ActivityLogChange(old=previous_state, new=Assembly.State.HIDDEN)

            assembly.save(update_fields=['state'])

            # add log entries
            assembly.log_activity(
                user=request.user,
                kind=ActivityLogEntry.Kind.STAFF,
                comment='MODERATION',
                **changes,
            )

            messages.success(request, f'assembly is now hidden: {assembly.slug}')

        else:
            messages.error(request, f'UNKNOWN ACTION: {action}')

        return redirect('backoffice:moderation-assembly-detail', pk=assembly.pk)
