from django.forms import ModelForm
from django.utils.translation import gettext_lazy as _

from core.models import Team


class TeamForm(ModelForm):
    class Meta:
        model = Team
        fields = [
            'name',
            'description_en',
            'description_de',
            'require_staff',
        ]
        help_texts = {
            'name': _('Team__name__help'),
        }

    def __init__(self, *args, instance: Team | None = None, conference, super_user: bool = False, **kwargs):
        self.create = instance is None
        self.conference = conference
        super().__init__(*args, instance=instance, **kwargs)
        if not super_user:
            del self.fields['require_staff']

    def save(self, commit: bool = True) -> Team:
        team = super().save(commit=False)
        team.conference = self.conference
        if commit:  # pragma: no branch
            team.save()
        return team
