from django_rich.management import RichCommand

from core.markdown import render_markdown_ex, store_relationships
from core.models import Assembly, ConferenceMember, Event, Room, StaticPage


class Command(RichCommand):
    def handle(self, *args, **options):
        # markdown is usually rerendered in the save() method, so calling save() is sufficient here for most models
        with self.console.status('Rerendering markdown for all events') as status:
            for event in Event.objects.all():
                event.save(update_fields=['description'])

            status.update('Rerendering markdown for all rooms')
            for room in Room.objects.all():
                room.save(update_fields=['description'])

            status.update('Rerendering markdown for all assemblies')
            for assembly in Assembly.objects.all():
                assembly.save(update_fields=['description'])

            status.update('Rerendering markdown for all conference members')
            for user in ConferenceMember.objects.all():
                user.save(update_fields=['description'])

            status.update('Rerendering markdown for all static pages')
            for page in StaticPage.objects.all():
                if page.public_revision > 0:
                    public_page = page.revisions.filter(revision=page.public_revision).first()
                    if public_page is None:
                        page.body_html = ''
                    else:
                        render_result = render_markdown_ex(page.conference, public_page.body)
                        page.body_html = render_result.document
                        store_relationships(page.conference, page, render_result)
                else:
                    page.body_html = ''
                page.save(update_fields=['body_html'])
