import time

from django.core.management.base import BaseCommand
from django.db import connection, transaction

from core.models import Assembly, Conference


class Command(BaseCommand):
    def handle(self, *args, **options):
        conf = Conference.objects.current_conference

        start_time = time.time()
        with transaction.atomic(), connection.cursor() as cursor:
            cursor.execute(
                """
                    SELECT e.id, lk.likes
                    FROM core_event AS e INNER JOIN core_eventlikecount AS lk ON e.id = lk.event1_id AND e.id=lk.event2_id
                    WHERE e.conference_id = %s AND is_public
            """,
                [conf.pk],
            )
            for row in cursor.fetchall():
                if row[1] == 0:
                    cursor.execute('UPDATE core_eventlikecount SET like_ratio=0 WHERE event1_id=%s', [row[0]])
                else:
                    cursor.execute('UPDATE core_eventlikecount SET like_ratio=likes*1000/%s WHERE event1_id=%s', [row[1], row[0]])
        ts = time.time() - start_time
        print(f'suggestion_tick (events) run took {ts:f} Seconds for Conference {conf}.')

        start_time = time.time()
        with transaction.atomic(), connection.cursor() as cursor:
            cursor.execute(
                f"""
                    SELECT a.id, lk.likes
                    FROM core_assembly AS a INNER JOIN core_assemblylikecount AS lk ON a.id = lk.assembly1_id AND a.id=lk.assembly2_id
                    WHERE a.conference_id = %s AND state IN ({','.join(['%s'] * len(Assembly.PUBLIC_STATES))})
            """,
                [conf.pk, *Assembly.PUBLIC_STATES],
            )
            for row in cursor.fetchall():
                if row[1] == 0:
                    cursor.execute('UPDATE core_assemblylikecount SET like_ratio=0 WHERE assembly1_id=%s', [row[0]])
                else:
                    cursor.execute('UPDATE core_assemblylikecount SET like_ratio=likes*1000/%s WHERE assembly1_id=%s', [row[1], row[0]])
        ts = time.time() - start_time
        print(f'suggestion_tick (events) run took {ts:f} Seconds for Conference {conf}.')
