import argparse
import json

from django.conf import settings
from django.core.exceptions import SuspiciousOperation
from django.db import transaction
from django_rich.management import RichCommand

from core.models.conference import Conference


class Command(RichCommand):
    def add_arguments(self, parser):
        parser.add_argument('--data-file', '-f', type=argparse.FileType('r'), help='the data file to load')

    def handle(self, *args, **options):
        datafile = options.get('data_file')
        data = json.load(datafile)

        conf = Conference.objects.get(pk=settings.SELECTED_CONFERENCE_ID)
        try:
            with transaction.atomic():
                assembly = conf.assemblies.create(slug='import')
                source = conf.schedule_sources.create(assembly=assembly)
                activity = source.load_data(data)
                raise SuspiciousOperation('fail deliberately to rollback any possible changes')
        except SuspiciousOperation:
            pass

        self.console.print_json(activity)
