from datetime import datetime

from django.template.defaulttags import register
from django.utils import timezone
from django.utils.translation import gettext_lazy as _

from core.models import Conference


@register.filter
def conference_time(timestamp: datetime, conf: Conference):
    if timestamp is None:
        return ''

    # derive conference day from given timestamp
    day = conf.get_conference_day(timestamp)
    day_i18n = _('Conference-day')

    # convert timestamp to current timezone
    local_ts = timezone.localtime(timestamp)

    # convert midnight to 24:00
    h = local_ts.hour
    if h == 0:
        h = 24
    m = local_ts.minute

    # return formatted string
    return f'{day_i18n} {day} @ {h:02d}:{m:02d}'
